def print_lol(the_list, level):
	for each_item in the_list:
		if isinstance(each_item, list):
			print_lol(each_item, level+2)
		else:
			for tab_stop in range(level):
				print('\t', end='')
			print(each_item)


from distutils.core import setup

setup(
	   name          =     'nester_k',
	   version       =     '1.2.0',
	   py_modules    =     ['nester'],
	   author        =     'll',
	   author_email  =     'll@ll.ll'
)